[−][src]Struct ring::digest::Context
A context for multi-step (Init-Update-Finish) digest calculations.
Examples
use ring::digest; let one_shot = digest::digest(&digest::SHA384, b"hello, world"); let mut ctx = digest::Context::new(&digest::SHA384); ctx.update(b"hello"); ctx.update(b", "); ctx.update(b"world"); let multi_part = ctx.finish(); assert_eq!(&one_shot.as_ref(), &multi_part.as_ref());
Fields
algorithm: &'static AlgorithmThe context's algorithm.
Methods
impl Context[src]
pub fn new(algorithm: &'static Algorithm) -> Context[src]
Constructs a new context.
pub fn update(&mut self, data: &[u8])[src]
Updates the digest with all the data in data. update may be called
zero or more times until finish is called. It must not be called
after finish has been called.
pub fn finish(self) -> Digest[src]
Finalizes the digest calculation and returns the digest value. finish
consumes the context so it cannot be (mis-)used after finish has been
called.
pub fn algorithm(&self) -> &'static Algorithm[src]
The algorithm that this context is using.